@@ -26,6 +26,7 @@
 
 #define _XOPEN_SOURCE /* glibc2 needs this */
 
+#include "gpx.h"
 #include "viking.h"
 #include <expat.h>
 #include <string.h>
@@ -70,6 +71,11 @@ typedef struct tag_mapping {
         const char *tag_name;           /* xpath-ish tag name */
 } tag_mapping;
 
+typedef struct {
+	GpxWritingOptions *options;
+	FILE *file;
+} GpxWritingContext;
+
 /*
  * xpath(ish) mappings between full tag paths and internal identifers.
  * These appear in the order they appear in the GPX specification.
@@ -583,8 +589,9 @@ entitize(const char * str)
 
 /* export GPX */
 
-static void gpx_write_waypoint ( const gchar *name, VikWaypoint *wp, FILE *f ) 
+static void gpx_write_waypoint ( const gchar *name, VikWaypoint *wp, GpxWritingContext *context ) 
 {
+  FILE *f = context->file;
   static struct LatLon ll;
   gchar *s_lat,*s_lon;
   gchar *tmp;
@@ -628,8 +635,9 @@ static void gpx_write_waypoint ( const gchar *name, VikWaypoint *wp, FILE *f )
   fprintf ( f, "</wpt>\n" );
 }
 
-static void gpx_write_trackpoint ( VikTrackpoint *tp, FILE *f )
+static void gpx_write_trackpoint ( VikTrackpoint *tp, GpxWritingContext *context )
 {
+  FILE *f = context->file;
   static struct LatLon ll;
   gchar *s_lat,*s_lon, *s_alt;
   static gchar time_buf[30];
@@ -641,19 +649,36 @@ static void gpx_write_trackpoint ( VikTrackpoint *tp, FILE *f )
   s_lat = a_coords_dtostr( ll.lat );
   s_lon = a_coords_dtostr( ll.lon );
   fprintf ( f, "  <trkpt lat=\"%s\" lon=\"%s\">\n", s_lat, s_lon );
-  g_free ( s_lat );
-  g_free ( s_lon );
+  g_free ( s_lat ); s_lat = NULL;
+  g_free ( s_lon ); s_lon = NULL;
 
+  s_alt = NULL;
   if ( tp->altitude != VIK_DEFAULT_ALTITUDE )
   {
     s_alt = a_coords_dtostr ( tp->altitude );
-    fprintf ( f, "    <ele>%s</ele>\n", s_alt );
-    g_free ( s_alt );
   }
+  else if ( context->options != NULL && context->options->force_ele )
+  {
+    s_alt = a_coords_dtostr ( 0 );
+  }
+  if (s_alt != NULL)
+    fprintf ( f, "    <ele>%s</ele>\n", s_alt );
+  g_free ( s_alt ); s_alt = NULL;
+  
+  time_buf[0] = '\0';
   if ( tp->has_timestamp ) {
     time_buf [ strftime ( time_buf, sizeof(time_buf)-1, GPX_TIME_FORMAT, localtime(&(tp->timestamp)) ) ] = '\0';
-    fprintf ( f, "    <time>%s</time>\n", time_buf );
   }
+  else if ( context->options != NULL && context->options->force_time )
+  {
+    time_t rawtime;
+    time ( &rawtime );
+  
+    time_buf [strftime ( time_buf, sizeof(time_buf)-1, GPX_TIME_FORMAT, localtime(&rawtime)) ] ='\0';
+  }
+  if ( time_buf[0] != '\0' )
+    fprintf ( f, "    <time>%s</time>\n", time_buf );
+  
   if (tp->extended && (tp->fix_mode >= VIK_GPS_MODE_2D)) {
     if (!isnan(tp->course)) {
       gchar *s_course = a_coords_dtostr(tp->course);
@@ -677,8 +702,9 @@ static void gpx_write_trackpoint ( VikTrackpoint *tp, FILE *f )
 }
 
 
-static void gpx_write_track ( const gchar *name, VikTrack *t, FILE *f )
+static void gpx_write_track ( const gchar *name, VikTrack *t, GpxWritingContext *context )
 {
+  FILE *f = context->file;
   gchar *tmp;
   gboolean first_tp_is_newsegment = FALSE; /* must temporarily make it not so, but we want to restore state. not that it matters. */
 
@@ -698,7 +724,7 @@ static void gpx_write_track ( const gchar *name, VikTrack *t, FILE *f )
   if ( t->trackpoints && t->trackpoints->data ) {
     first_tp_is_newsegment = VIK_TRACKPOINT(t->trackpoints->data)->newsegment;
     VIK_TRACKPOINT(t->trackpoints->data)->newsegment = FALSE; /* so we won't write </trkseg><trkseg> already */
-    g_list_foreach ( t->trackpoints, (GFunc) gpx_write_trackpoint, f );
+    g_list_foreach ( t->trackpoints, (GFunc) gpx_write_trackpoint, context );
     VIK_TRACKPOINT(t->trackpoints->data)->newsegment = first_tp_is_newsegment; /* restore state */
   }
 
@@ -719,17 +745,73 @@ static void gpx_write_footer( FILE *f )
   fprintf(f, "</gpx>\n");
 }
 
+
+
+typedef struct {
+  VikWaypoint *wp;
+  const gchar *name;
+} gpx_waypoint_and_name;
+
+typedef struct {
+  gpx_waypoint_and_name *wps;
+  guint i;
+  guint n_wps;
+} gpx_gather_waypoints_passalong_t;
+
+static void gpx_collect_waypoint ( const gchar *name, VikWaypoint *wp, gpx_gather_waypoints_passalong_t *passalong )
+{
+  if ( passalong->i < passalong->n_wps ) {
+    passalong->wps[passalong->i].name = name;
+    passalong->wps[passalong->i].wp = wp;
+    passalong->i++;
+  }
+}
+
+static int gpx_waypoint_and_name_compar(const void *x, const void *y)
+{
+  gpx_waypoint_and_name *a = (gpx_waypoint_and_name *)x;
+  gpx_waypoint_and_name *b = (gpx_waypoint_and_name *)y;
+  return strcmp(a->name,b->name);
+}
+
 void a_gpx_write_file( VikTrwLayer *vtl, FILE *f )
 {
+	a_gpx_write_file_options(NULL, vtl, f);
+}
+
+void a_gpx_write_file_options ( GpxWritingOptions *options, VikTrwLayer *vtl, FILE *f )
+{
+  GpxWritingContext context = { options, f };
+  int i;
+
   gpx_write_header ( f );
-  g_hash_table_foreach ( vik_trw_layer_get_waypoints ( vtl ), (GHFunc) gpx_write_waypoint, f );
-  g_hash_table_foreach ( vik_trw_layer_get_tracks ( vtl ), (GHFunc) gpx_write_track, f );
+
+
+  gpx_gather_waypoints_passalong_t passalong;
+  passalong.n_wps = g_hash_table_size ( vik_trw_layer_get_waypoints ( vtl ) );
+  passalong.i = 0;
+  passalong.wps = g_new(gpx_waypoint_and_name,passalong.n_wps);
+  g_hash_table_foreach ( vik_trw_layer_get_waypoints ( vtl ), (GHFunc) gpx_collect_waypoint, &passalong );
+  /* gather waypoints in a list, then sort */
+  qsort(passalong.wps, passalong.n_wps, sizeof(gpx_waypoint_and_name), gpx_waypoint_and_name_compar);
+  for ( i = 0; i < passalong.n_wps; i++ )
+    gpx_write_waypoint ( passalong.wps[i].name, passalong.wps[i].wp, &context);
+  g_free ( passalong.wps );
+
+  g_hash_table_foreach ( vik_trw_layer_get_tracks ( vtl ), (GHFunc) gpx_write_track, &context );
+
   gpx_write_footer ( f );
 }
 
 void a_gpx_write_track_file ( const gchar *name, VikTrack *t, FILE *f )
 {
+  a_gpx_write_track_file_options ( NULL, name, t, f );
+}
+
+void a_gpx_write_track_file_options ( GpxWritingOptions *options, const gchar *name, VikTrack *t, FILE *f )
+{
+  GpxWritingContext context = {options, f};
   gpx_write_header ( f );
-  gpx_write_track ( name, t, f );
+  gpx_write_track ( name, t, &context );
   gpx_write_footer ( f );
 }
